@@ -10,7 +10,11 @@
 """
 import os
 import sys
-import thread
+try:
+    import thread
+except ImportError:
+    # for python 3.1,3.2
+    import _thread as thread
 import threading
 import traceback
 from itertools import chain
@@ -18,7 +22,7 @@ from weakref import ref as weakref
 from datetime import datetime
 
 from logbook.helpers import to_safe_json, parse_iso8601, cached_property, \
-     F, _py3
+     F, PY2, u, string_types, iteritems, integer_types
 try:
     from logbook._speedups import group_reflected_property, \
          ContextStackManager, StackedObject
@@ -26,6 +30,47 @@ except ImportError:
     from logbook._fallback import group_reflected_property, \
          ContextStackManager, StackedObject
 
+_datetime_factory = datetime.utcnow
+def set_datetime_format(datetime_format):
+    """
+    Set the format for the datetime objects created, which are then
+    made available as the :py:attr:`LogRecord.time` attribute of
+    :py:class:`LogRecord` instances.
+
+    :param datetime_format: Indicates how to generate datetime objects.  Possible values are:
+
+         "utc"
+             :py:attr:`LogRecord.time` will be a datetime in UTC time zone (but not time zone aware)
+         "local"
+             :py:attr:`LogRecord.time` will be a datetime in local time zone (but not time zone aware)
+
+    This function defaults to creating datetime objects in UTC time,
+    using `datetime.utcnow()
+    <http://docs.python.org/3/library/datetime.html#datetime.datetime.utcnow>`_,
+    so that logbook logs all times in UTC time by default.  This is
+    recommended in case you have multiple software modules or
+    instances running in different servers in different time zones, as
+    it makes it simple and less error prone to correlate logging
+    across the different servers.
+
+    On the other hand if all your software modules are running in the
+    same time zone and you have to correlate logging with third party
+    modules already logging in local time, it can be more convenient
+    to have logbook logging to local time instead of UTC.  Local time
+    logging can be enabled like this::
+
+       import logbook
+       from datetime import datetime
+       logbook.set_datetime_format("local")
+
+    """
+    global _datetime_factory
+    if datetime_format == "utc":
+        _datetime_factory = datetime.utcnow
+    elif datetime_format == "local":
+        _datetime_factory = datetime.now
+    else:
+        raise ValueError("Invalid value %r.  Valid values are 'utc' and 'local'." % (datetime_format,))
 
 # make sure to sync these up with _speedups.pyx
 CRITICAL = 6
@@ -45,21 +90,21 @@ _level_names = {
     DEBUG:      'DEBUG',
     NOTSET:     'NOTSET'
 }
-_reverse_level_names = dict((v, k) for (k, v) in _level_names.iteritems())
+_reverse_level_names = dict((v, k) for (k, v) in iteritems(_level_names))
 _missing = object()
 
 
 # on python 3 we can savely assume that frame filenames will be in
 # unicode, on Python 2 we have to apply a trick.
-if _py3:
-    def _convert_frame_filename(fn):
-        return fn
-else:
+if PY2:
     def _convert_frame_filename(fn):
         if isinstance(fn, unicode):
             fn = fn.decode(sys.getfilesystemencoding() or 'utf-8',
                            'replace')
         return fn
+else:
+    def _convert_frame_filename(fn):
+        return fn
 
 
 def level_name_property():
@@ -78,7 +123,7 @@ def level_name_property():
 
 def lookup_level(level):
     """Return the integer representation of a logging level."""
-    if isinstance(level, (int, long)):
+    if isinstance(level, integer_types):
         return level
     try:
         return _reverse_level_names[level]
@@ -102,10 +147,10 @@ class ExtraDict(dict):
             try:
                 return dict.__getitem__(self, key)
             except KeyError:
-                return u''
+                return u('')
     else:
         def __missing__(self, key):
-            return u''
+            return u('')
 
     def copy(self):
         return self.__class__(self)
@@ -357,7 +402,7 @@ class LogRecord(object):
         assert not self.late, 'heavy init is no longer possible'
         self.heavy_initialized = True
         self.process = os.getpid()
-        self.time = datetime.utcnow()
+        self.time = _datetime_factory()
         if self.frame is None and Flags.get_flag('introspection', True):
             self.frame = sys._getframe(1)
 
@@ -396,7 +441,7 @@ class LogRecord(object):
         """
         self.pull_information()
         rv = {}
-        for key, value in self.__dict__.iteritems():
+        for key, value in iteritems(self.__dict__):
             if key[:1] != '_' and key not in self._noned_on_close:
                 rv[key] = value
         # the extra dict is exported as regular dict
@@ -423,7 +468,7 @@ class LogRecord(object):
             setattr(self, key, None)
         self._information_pulled = True
         self._channel = None
-        if isinstance(self.time, basestring):
+        if isinstance(self.time, string_types):
             self.time = parse_iso8601(self.time)
         return self
 
@@ -439,7 +484,11 @@ class LogRecord(object):
                 # Assume an unicode message but mixed-up args
                 msg = self.msg.encode('utf-8', 'replace')
                 return F(msg).format(*self.args, **self.kwargs)
-            except UnicodeEncodeError:
+            except (UnicodeEncodeError, AttributeError):
+                # we catch AttributeError since if msg is bytes, it won't have the 'format' method
+                if sys.exc_info()[0] is AttributeError and (PY2 or not isinstance(self.msg, bytes)):
+                    # this is not the case we thought it is...
+                    raise
                 # Assume encoded message with unicode args.
                 # The assumption of utf8 as input encoding is just a guess,
                 # but this codepath is unlikely (if the message is a constant
@@ -447,11 +496,12 @@ class LogRecord(object):
                 msg = self.msg.decode('utf-8', 'replace')
                 return F(msg).format(*self.args, **self.kwargs)
 
-        except Exception, e:
+        except Exception:
             # this obviously will not give a proper error message if the
             # information was not pulled and the log record no longer has
             # access to the frame.  But there is not much we can do about
             # that.
+            e = sys.exc_info()[1]
             errormsg = F('Could not format message with provided '
                          'arguments: {err}\n  msg={msg!r}\n  '
                          'args={args!r} \n  kwargs={kwargs!r}.\n'
@@ -460,7 +510,7 @@ class LogRecord(object):
                 kwargs=self.kwargs, file=self.filename,
                 lineno=self.lineno
             )
-            if not _py3:
+            if PY2:
                 errormsg = errormsg.encode('utf-8')
             raise TypeError(errormsg)
 
@@ -555,7 +605,7 @@ class LogRecord(object):
         """
         if self.exc_info is not None:
             rv = ''.join(traceback.format_exception(*self.exc_info))
-            if not _py3:
+            if PY2:
                 rv = rv.decode('utf-8', 'replace')
             return rv.rstrip()
 
@@ -564,7 +614,7 @@ class LogRecord(object):
         """The name of the exception."""
         if self.exc_info is not None:
             cls = self.exc_info[0]
-            return unicode(cls.__module__ + '.' + cls.__name__)
+            return u(cls.__module__ + '.' + cls.__name__)
 
     @property
     def exception_shortname(self):
@@ -577,7 +627,7 @@ class LogRecord(object):
         if self.exc_info is not None:
             val = self.exc_info[1]
             try:
-                return unicode(val)
+                return u(str(val))
             except UnicodeError:
                 return str(val).decode('utf-8', 'replace')
 
