@@ -21,22 +21,22 @@ except ImportError:
 import threading
 import traceback
 from datetime import datetime, timedelta
-from itertools import izip
 from threading import Lock
 from collections import deque
 
 from logbook.base import CRITICAL, ERROR, WARNING, NOTICE, INFO, DEBUG, \
      NOTSET, level_name_property, _missing, lookup_level, \
      Flags, ContextObject, ContextStackManager
-from logbook.helpers import any, rename, F, b, _is_text_stream
+from logbook.helpers import rename, F, b, _is_text_stream, is_unicode, PY2, \
+    zip, xrange, string_types, integer_types, iteritems, u, reraise
 
 
 DEFAULT_FORMAT_STRING = (
-    u'[{record.time:%Y-%m-%d %H:%M}] '
-    u'{record.level_name}: {record.channel}: {record.message}'
+    u('[{record.time:%Y-%m-%d %H:%M}] '
+      '{record.level_name}: {record.channel}: {record.message}')
 )
-SYSLOG_FORMAT_STRING = u'{record.channel}: {record.message}'
-NTLOG_FORMAT_STRING = u'''\
+SYSLOG_FORMAT_STRING = u('{record.channel}: {record.message}')
+NTLOG_FORMAT_STRING = u('''\
 Message Level: {record.level_name}
 Location: {record.filename}:{record.lineno}
 Module: {record.module}
@@ -46,10 +46,10 @@ Exact Time: {record.time:%Y-%m-%d %H:%M:%S}
 Event provided Message:
 
 {record.message}
-'''
+''')
 TEST_FORMAT_STRING = \
-u'[{record.level_name}] {record.channel}: {record.message}'
-MAIL_FORMAT_STRING = u'''\
+u('[{record.level_name}] {record.channel}: {record.message}')
+MAIL_FORMAT_STRING = u('''\
 Subject: {handler.subject}
 
 Message type:       {record.level_name}
@@ -61,22 +61,19 @@ Time:               {record.time:%Y-%m-%d %H:%M:%S}
 Message:
 
 {record.message}
-'''
-MAIL_RELATED_FORMAT_STRING = u'''\
+''')
+MAIL_RELATED_FORMAT_STRING = u('''\
 Message type:       {record.level_name}
 Location:           {record.filename}:{record.lineno}
 Module:             {record.module}
 Function:           {record.func_name}
 {record.message}
-'''
+''')
 
 SYSLOG_PORT = 514
 
 REGTYPE = type(re.compile("I'm a regular expression!"))
 
-_py3 = sys.version_info >= (3, 0)
-
-
 def create_syshandler(application_name, level=NOTSET):
     """Creates the handler the operating system provides.  On Unix systems
     this creates a :class:`SyslogHandler`, on Windows sytems it will
@@ -293,7 +290,7 @@ class Handler(ContextObject):
         try:
             behaviour = Flags.get_flag('errors', 'print')
             if behaviour == 'raise':
-                raise exc_info[0], exc_info[1], exc_info[2]
+                reraise(exc_info[0], exc_info[1], exc_info[2])
             elif behaviour == 'print':
                 traceback.print_exception(*(exc_info + (None, sys.stderr)))
                 sys.stderr.write('Logged from file %s, line %s\n' % (
@@ -377,7 +374,7 @@ class StringFormatter(object):
         line = self.format_record(record, handler)
         exc = self.format_exception(record)
         if exc:
-            line += u'\n' + exc
+            line += u('\n') + exc
         return line
 
 
@@ -423,7 +420,7 @@ class HashingHandlerMixin(object):
         """Returns a hashlib object with the hash of the record."""
         hash = sha1()
         hash.update(('%d\x00' % record.level).encode('ascii'))
-        hash.update((record.channel or u'').encode('utf-8') + b('\x00'))
+        hash.update((record.channel or u('')).encode('utf-8') + b('\x00'))
         hash.update(record.filename.encode('utf-8') + b('\x00'))
         hash.update(b(str(record.lineno)))
         return hash
@@ -437,6 +434,7 @@ class HashingHandlerMixin(object):
         """
         return self.hash_record_raw(record).hexdigest()
 
+_NUMBER_TYPES = integer_types + (float,)
 
 class LimitingHandlerMixin(HashingHandlerMixin):
     """Mixin class for handlers that want to limit emitting records.
@@ -457,7 +455,7 @@ class LimitingHandlerMixin(HashingHandlerMixin):
         self._record_limits = {}
         if record_delta is None:
             record_delta = timedelta(seconds=60)
-        elif isinstance(record_delta, (int, long, float)):
+        elif isinstance(record_delta, _NUMBER_TYPES):
             record_delta = timedelta(seconds=record_delta)
         self.record_delta = record_delta
 
@@ -549,8 +547,7 @@ class StreamHandler(Handler, StringFormatterHandlerMixin):
         """Formats the record and encodes it to the stream encoding."""
         stream = self.stream
         rv = self.format(record) + '\n'
-        if isinstance(rv, unicode) \
-           and (not _py3 or not _is_text_stream(stream)):
+        if not is_unicode(rv) and (PY2 or not _is_text_stream(stream)):
             enc = self.encoding
             if enc is None:
                 enc = getattr(stream, 'encoding', None) or 'utf-8'
@@ -600,7 +597,7 @@ class FileHandler(StreamHandler):
     def write(self, item):
         if self.stream is None:
             self._open()
-        if _py3 and isinstance(item, bytes):
+        if not PY2 and isinstance(item, bytes):
             self.stream.buffer.write(item)
         else:
             self.stream.write(item)
@@ -648,7 +645,8 @@ class MonitoringFileHandler(FileHandler):
         else:
             try:
                 st = os.stat(self._filename)
-            except OSError, e:
+            except OSError:
+                e = sys.exc_info()[1]
                 if e.errno != 2:
                     raise
                 self._last_stat = None, None
@@ -761,7 +759,8 @@ class RotatingFileHandler(FileHandler):
             dst = '%s.%d' % (self._filename, x + 1)
             try:
                 rename(src, dst)
-            except OSError, e:
+            except OSError:
+                e = sys.exc_info()[1]
                 if e.errno != errno.ENOENT:
                     raise
         rename(self._filename, self._filename + '.1')
@@ -892,8 +891,8 @@ class TestHandler(Handler, StringFormatterHandlerMixin):
         """Captures the formatted log records as unicode strings."""
         if len(self._formatted_records) != self.records or \
            any(r1 != r2 for r1, (r2, f) in
-               izip(self.records, self._formatted_records)):
-            self._formatted_records = map(self.format, self.records)
+               zip(self.records, self._formatted_records)):
+            self._formatted_records = [self.format(r) for r in self.records]
             self._formatted_record_cache = list(self.records)
         return self._formatted_records
 
@@ -1032,7 +1031,7 @@ class MailHandler(Handler, StringFormatterHandlerMixin,
     """
     default_format_string = MAIL_FORMAT_STRING
     default_related_format_string = MAIL_RELATED_FORMAT_STRING
-    default_subject = u'Server Error in Application'
+    default_subject = u('Server Error in Application')
 
     #: the maximum number of record hashes in the cache for the limiting
     #: feature.  Afterwards, record_cache_prune percent of the oldest
@@ -1085,12 +1084,8 @@ class MailHandler(Handler, StringFormatterHandlerMixin,
         (:class:`email.message.Message`).  `suppressed` is the number
         of mails not sent if the `record_limit` feature is active.
         """
-        try:
-            from email.message import Message
-            from email.header import Header
-        except ImportError:  # Python 2.4
-            from email.Message import Message
-            from email.Header import Header
+        from email.message import Message
+        from email.header import Header
         msg = Message()
         msg.set_charset('utf-8')
         lineiter = iter(self.format(record).splitlines())
@@ -1112,7 +1107,7 @@ class MailHandler(Handler, StringFormatterHandlerMixin,
             body += '\r\n\r\nThis message occurred additional %d ' \
                     'time(s) and was suppressed' % suppressed
 
-        # inconsistency in Python 2.4 and 2.5
+        # inconsistency in Python 2.5
         # other versions correctly return msg.get_payload() as str
         if sys.version_info < (2, 6) and isinstance(body, unicode):
             body = body.encode('utf-8')
@@ -1131,10 +1126,7 @@ class MailHandler(Handler, StringFormatterHandlerMixin,
         with headers and date.  `suppressed` is the number of mails
         that were not send if the `record_limit` feature is active.
         """
-        try:
-            from email.utils import formatdate
-        except ImportError:  # Python 2.4
-            from email.Utils import formatdate
+        from email.utils import formatdate
         msg = self.message_from_record(record, suppressed)
         msg['From'] = self.from_addr
         msg['Date'] = formatdate()
@@ -1314,7 +1306,7 @@ class SyslogHandler(Handler, StringFormatterHandlerMixin):
         self.facility = facility
         self.socktype = socktype
 
-        if isinstance(address, basestring):
+        if isinstance(address, string_types):
             self._connect_unixsocket()
         else:
             self._connect_netsocket()
@@ -1343,10 +1335,10 @@ class SyslogHandler(Handler, StringFormatterHandlerMixin):
         return (facility << 3) | priority
 
     def emit(self, record):
-        prefix = u''
+        prefix = u('')
         if self.application_name is not None:
-            prefix = self.application_name + u':'
-        self.send_to_socket((u'<%d>%s%s\x00' % (
+            prefix = self.application_name + u(':')
+        self.send_to_socket((u('<%d>%s%s\x00') % (
             self.encode_priority(record),
             prefix,
             self.format(record)
